
#ifndef __SIMPLE_SAMPLER_H__
#define __SIMPLE_SAMPLER_H__

#include "sampling.h"


class SimpleStratifiedSampler {

public:

	// This is a sampler for use when producing an image of size pixelsX by pixelsY
	// a total of samplesPerDim*samplerPerDim samples will be taken per pixel.
	// See PBRT for a description of what other samples (other than spatial samples on
	// the film) that Samplers generate.  
	// jitterSensor -- whether or not to jitter spatial samples on the sensor
	// jitterNonSensor -- whether or not to jitter all other samples
	SimpleStratifiedSampler(int pixelsX, int pixelsY,
							int samplesPerDim, bool jitterSensor, bool jitterNonSensor);

	~SimpleStratifiedSampler() {
		FreeAligned(imageSamples);
	}

	bool GetNextSample(Sample *sample);
	void reset();

private:

	int xPixelStart, yPixelStart;
	int xPixelEnd, yPixelEnd;
	int xPixelSamples, yPixelSamples;
	bool jitterSensorSamples;
	bool jitterNonSensorSamples;
	int xPos, yPos;
	float *imageSamples, *lensSamples, *timeSamples;
	int samplePos;
	
};


#endif  // __SIMPLE_SAMPLER_H__

